/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef JAC_AP_SLAMSERVICE_SLAMSERVICE_PROXY_H
#define JAC_AP_SLAMSERVICE_SLAMSERVICE_PROXY_H

#include "ara/com/internal/proxy/proxy_adapter.h"
#include "ara/com/internal/proxy/event_adapter.h"
#include "ara/com/internal/proxy/field_adapter.h"
#include "ara/com/internal/proxy/method_adapter.h"
#include "ara/com/crc_verification.h"
#include "jac/ap/slamservice/slamservice_common.h"
#include <string>

namespace jac {
namespace ap {
namespace slamservice {
namespace proxy {
namespace events {
    using PositionEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::position>;
    using AttributeEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::attribute>;
    using LinePointEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::line_point>;
    using LineEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::line>;
    using SpeedLimitEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::speed_limit>;
    using TrafficObjectEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::traffic_object>;
    using LaneEventSlam = ara::com::internal::proxy::event::EventAdapter<::dpc::Lane>;
    using RoadEdgeEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::RoadEdge>;
    using SLAMRoadModelEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::slam_road_model>;
    using AdjacentExtendLaneStructEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::AdjacentExtendLaneStruct>;
    using SMAStructEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::SMAStruct>;
    using WPExtendLaneStructEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::WPExtendLaneStruct>;
    using RemindWayPointStructEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::RemindWayPointStruct>;
    using ControlWayPointStructEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::ControlWayPointStruct>;
    using MsgHeaderEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::MsgHeader>;
    using TransitLaneStructEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::TransitLaneStruct>;
    using ControlWayPointsEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::ControlWaypoints>;
    using SLAMLocalEgoOdomEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::SLAMLocalEgoOdom>;
    using SLAMOdometryEvent = ara::com::internal::proxy::event::EventAdapter<::dpc::slam_odometry>;
    static constexpr ara::com::internal::EntityId SLAMServicePositionEventId = 18038U; //PositionEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceAttributeEventId = 36926U; //AttributeEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceLinePointEventId = 45027U; //LinePointEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceLineEventId = 45904U; //LineEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceSpeedLimitEventId = 28595U; //SpeedLimitEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceTrafficObjectEventId = 6716U; //TrafficObjectEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceLaneEventSlamId = 55536U; //LaneEventSlam_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceRoadEdgeEventId = 62920U; //RoadEdgeEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceSLAMRoadModelEventId = 5227U; //SLAMRoadModelEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceAdjacentExtendLaneStructEventId = 49460U; //AdjacentExtendLaneStructEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceSMAStructEventId = 18332U; //SMAStructEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceWPExtendLaneStructEventId = 10669U; //WPExtendLaneStructEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceRemindWayPointStructEventId = 56635U; //RemindWayPointStructEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceControlWayPointStructEventId = 61573U; //ControlWayPointStructEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceMsgHeaderEventId = 27525U; //MsgHeaderEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceTransitLaneStructEventId = 7649U; //TransitLaneStructEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceControlWayPointsEventId = 33464U; //ControlWayPointsEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceSLAMLocalEgoOdomEventId = 7254U; //SLAMLocalEgoOdomEvent_event_hash
    static constexpr ara::com::internal::EntityId SLAMServiceSLAMOdometryEventId = 55549U; //SLAMOdometryEvent_event_hash
}

namespace fields {
}

namespace methods {

} // namespace methods

class SLAMServiceProxy {
private:
    std::shared_ptr<ara::com::internal::proxy::ProxyAdapter> proxyAdapter;
public:
    using HandleType = ara::com::HandleType;
    class ConstructionToken {
    public:
        explicit ConstructionToken(const std::shared_ptr<ara::com::internal::proxy::ProxyAdapter> & proxy)
            : proxyAdapter(proxy),
              PositionEvent(proxyAdapter->GetProxy(), events::SLAMServicePositionEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              AttributeEvent(proxyAdapter->GetProxy(), events::SLAMServiceAttributeEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              LinePointEvent(proxyAdapter->GetProxy(), events::SLAMServiceLinePointEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              LineEvent(proxyAdapter->GetProxy(), events::SLAMServiceLineEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              SpeedLimitEvent(proxyAdapter->GetProxy(), events::SLAMServiceSpeedLimitEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              TrafficObjectEvent(proxyAdapter->GetProxy(), events::SLAMServiceTrafficObjectEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              LaneEventSlam(proxyAdapter->GetProxy(), events::SLAMServiceLaneEventSlamId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              RoadEdgeEvent(proxyAdapter->GetProxy(), events::SLAMServiceRoadEdgeEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              SLAMRoadModelEvent(proxyAdapter->GetProxy(), events::SLAMServiceSLAMRoadModelEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              AdjacentExtendLaneStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceAdjacentExtendLaneStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              SMAStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceSMAStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              WPExtendLaneStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceWPExtendLaneStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              RemindWayPointStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceRemindWayPointStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              ControlWayPointStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceControlWayPointStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              MsgHeaderEvent(proxyAdapter->GetProxy(), events::SLAMServiceMsgHeaderEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              TransitLaneStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceTransitLaneStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              ControlWayPointsEvent(proxyAdapter->GetProxy(), events::SLAMServiceControlWayPointsEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              SLAMLocalEgoOdomEvent(proxyAdapter->GetProxy(), events::SLAMServiceSLAMLocalEgoOdomEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
              SLAMOdometryEvent(proxyAdapter->GetProxy(), events::SLAMServiceSLAMOdometryEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()){
        }

        ConstructionToken(ConstructionToken&& other) = default;
        ConstructionToken& operator=(ConstructionToken && other) = default;

        ConstructionToken(const ConstructionToken&) = delete;
        ConstructionToken& operator = (const ConstructionToken&) = delete;
        
        virtual ~ConstructionToken() = default;

        /* Do not use such internal interfaces!!! */
        ara::core::Result<void> InitializeAll()
        {
            ara::core::Result<void> initResult;
            return initResult;
        }
        std::shared_ptr<ara::com::internal::proxy::ProxyAdapter> GetProxyAdapter()
        {
            return proxyAdapter;
        }
        events::PositionEvent GetPositionEvent() noexcept { return std::move(PositionEvent); }
        events::AttributeEvent GetAttributeEvent() noexcept { return std::move(AttributeEvent); }
        events::LinePointEvent GetLinePointEvent() noexcept { return std::move(LinePointEvent); }
        events::LineEvent GetLineEvent() noexcept { return std::move(LineEvent); }
        events::SpeedLimitEvent GetSpeedLimitEvent() noexcept { return std::move(SpeedLimitEvent); }
        events::TrafficObjectEvent GetTrafficObjectEvent() noexcept { return std::move(TrafficObjectEvent); }
        events::LaneEventSlam GetLaneEventSlam() noexcept { return std::move(LaneEventSlam); }
        events::RoadEdgeEvent GetRoadEdgeEvent() noexcept { return std::move(RoadEdgeEvent); }
        events::SLAMRoadModelEvent GetSLAMRoadModelEvent() noexcept { return std::move(SLAMRoadModelEvent); }
        events::AdjacentExtendLaneStructEvent GetAdjacentExtendLaneStructEvent() noexcept { return std::move(AdjacentExtendLaneStructEvent); }
        events::SMAStructEvent GetSMAStructEvent() noexcept { return std::move(SMAStructEvent); }
        events::WPExtendLaneStructEvent GetWPExtendLaneStructEvent() noexcept { return std::move(WPExtendLaneStructEvent); }
        events::RemindWayPointStructEvent GetRemindWayPointStructEvent() noexcept { return std::move(RemindWayPointStructEvent); }
        events::ControlWayPointStructEvent GetControlWayPointStructEvent() noexcept { return std::move(ControlWayPointStructEvent); }
        events::MsgHeaderEvent GetMsgHeaderEvent() noexcept { return std::move(MsgHeaderEvent); }
        events::TransitLaneStructEvent GetTransitLaneStructEvent() noexcept { return std::move(TransitLaneStructEvent); }
        events::ControlWayPointsEvent GetControlWayPointsEvent() noexcept { return std::move(ControlWayPointsEvent); }
        events::SLAMLocalEgoOdomEvent GetSLAMLocalEgoOdomEvent() noexcept { return std::move(SLAMLocalEgoOdomEvent); }
        events::SLAMOdometryEvent GetSLAMOdometryEvent() noexcept { return std::move(SLAMOdometryEvent); }
    private:
        std::shared_ptr<ara::com::internal::proxy::ProxyAdapter> proxyAdapter;
        events::PositionEvent PositionEvent;
        events::AttributeEvent AttributeEvent;
        events::LinePointEvent LinePointEvent;
        events::LineEvent LineEvent;
        events::SpeedLimitEvent SpeedLimitEvent;
        events::TrafficObjectEvent TrafficObjectEvent;
        events::LaneEventSlam LaneEventSlam;
        events::RoadEdgeEvent RoadEdgeEvent;
        events::SLAMRoadModelEvent SLAMRoadModelEvent;
        events::AdjacentExtendLaneStructEvent AdjacentExtendLaneStructEvent;
        events::SMAStructEvent SMAStructEvent;
        events::WPExtendLaneStructEvent WPExtendLaneStructEvent;
        events::RemindWayPointStructEvent RemindWayPointStructEvent;
        events::ControlWayPointStructEvent ControlWayPointStructEvent;
        events::MsgHeaderEvent MsgHeaderEvent;
        events::TransitLaneStructEvent TransitLaneStructEvent;
        events::ControlWayPointsEvent ControlWayPointsEvent;
        events::SLAMLocalEgoOdomEvent SLAMLocalEgoOdomEvent;
        events::SLAMOdometryEvent SLAMOdometryEvent;
    };

    virtual ~SLAMServiceProxy()
    {
        PositionEvent.UnsetReceiveHandler();
        PositionEvent.Unsubscribe();
        AttributeEvent.UnsetReceiveHandler();
        AttributeEvent.Unsubscribe();
        LinePointEvent.UnsetReceiveHandler();
        LinePointEvent.Unsubscribe();
        LineEvent.UnsetReceiveHandler();
        LineEvent.Unsubscribe();
        SpeedLimitEvent.UnsetReceiveHandler();
        SpeedLimitEvent.Unsubscribe();
        TrafficObjectEvent.UnsetReceiveHandler();
        TrafficObjectEvent.Unsubscribe();
        LaneEventSlam.UnsetReceiveHandler();
        LaneEventSlam.Unsubscribe();
        RoadEdgeEvent.UnsetReceiveHandler();
        RoadEdgeEvent.Unsubscribe();
        SLAMRoadModelEvent.UnsetReceiveHandler();
        SLAMRoadModelEvent.Unsubscribe();
        AdjacentExtendLaneStructEvent.UnsetReceiveHandler();
        AdjacentExtendLaneStructEvent.Unsubscribe();
        SMAStructEvent.UnsetReceiveHandler();
        SMAStructEvent.Unsubscribe();
        WPExtendLaneStructEvent.UnsetReceiveHandler();
        WPExtendLaneStructEvent.Unsubscribe();
        RemindWayPointStructEvent.UnsetReceiveHandler();
        RemindWayPointStructEvent.Unsubscribe();
        ControlWayPointStructEvent.UnsetReceiveHandler();
        ControlWayPointStructEvent.Unsubscribe();
        MsgHeaderEvent.UnsetReceiveHandler();
        MsgHeaderEvent.Unsubscribe();
        TransitLaneStructEvent.UnsetReceiveHandler();
        TransitLaneStructEvent.Unsubscribe();
        ControlWayPointsEvent.UnsetReceiveHandler();
        ControlWayPointsEvent.Unsubscribe();
        SLAMLocalEgoOdomEvent.UnsetReceiveHandler();
        SLAMLocalEgoOdomEvent.Unsubscribe();
        SLAMOdometryEvent.UnsetReceiveHandler();
        SLAMOdometryEvent.Unsubscribe();

    }

    explicit SLAMServiceProxy(const HandleType &handle)
        : proxyAdapter(std::make_shared<ara::com::internal::proxy::ProxyAdapter>(::jac::ap::slamservice::SLAMService::ServiceIdentifier, handle)),
          PositionEvent(proxyAdapter->GetProxy(), events::SLAMServicePositionEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          AttributeEvent(proxyAdapter->GetProxy(), events::SLAMServiceAttributeEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          LinePointEvent(proxyAdapter->GetProxy(), events::SLAMServiceLinePointEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          LineEvent(proxyAdapter->GetProxy(), events::SLAMServiceLineEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          SpeedLimitEvent(proxyAdapter->GetProxy(), events::SLAMServiceSpeedLimitEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          TrafficObjectEvent(proxyAdapter->GetProxy(), events::SLAMServiceTrafficObjectEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          LaneEventSlam(proxyAdapter->GetProxy(), events::SLAMServiceLaneEventSlamId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          RoadEdgeEvent(proxyAdapter->GetProxy(), events::SLAMServiceRoadEdgeEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          SLAMRoadModelEvent(proxyAdapter->GetProxy(), events::SLAMServiceSLAMRoadModelEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          AdjacentExtendLaneStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceAdjacentExtendLaneStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          SMAStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceSMAStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          WPExtendLaneStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceWPExtendLaneStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          RemindWayPointStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceRemindWayPointStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          ControlWayPointStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceControlWayPointStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          MsgHeaderEvent(proxyAdapter->GetProxy(), events::SLAMServiceMsgHeaderEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          TransitLaneStructEvent(proxyAdapter->GetProxy(), events::SLAMServiceTransitLaneStructEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          ControlWayPointsEvent(proxyAdapter->GetProxy(), events::SLAMServiceControlWayPointsEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          SLAMLocalEgoOdomEvent(proxyAdapter->GetProxy(), events::SLAMServiceSLAMLocalEgoOdomEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()),
          SLAMOdometryEvent(proxyAdapter->GetProxy(), events::SLAMServiceSLAMOdometryEventId, proxyAdapter->GetHandle(), proxyAdapter->GetServiceInterfaceInfo()){
        }

    void ThrowError(const ara::core::Result<void>& result) const
    {
        if (!(result.HasValue())) {
#ifndef NOT_SUPPORT_EXCEPTIONS
            ara::core::ErrorCode errorcode(result.Error());
            throw ara::com::ComException(std::move(errorcode));
#else
            std::cerr << "Error: Not support exception, create proxy failed!"<< std::endl;
#endif
        }
    }

    SLAMServiceProxy(const SLAMServiceProxy&) = delete;
    SLAMServiceProxy& operator=(const SLAMServiceProxy&) = delete;

    SLAMServiceProxy(SLAMServiceProxy&&) = default;
    SLAMServiceProxy& operator=(SLAMServiceProxy&&) = default;
    SLAMServiceProxy(ConstructionToken&& token) noexcept
        : proxyAdapter(token.GetProxyAdapter()),
          PositionEvent(token.GetPositionEvent()),
          AttributeEvent(token.GetAttributeEvent()),
          LinePointEvent(token.GetLinePointEvent()),
          LineEvent(token.GetLineEvent()),
          SpeedLimitEvent(token.GetSpeedLimitEvent()),
          TrafficObjectEvent(token.GetTrafficObjectEvent()),
          LaneEventSlam(token.GetLaneEventSlam()),
          RoadEdgeEvent(token.GetRoadEdgeEvent()),
          SLAMRoadModelEvent(token.GetSLAMRoadModelEvent()),
          AdjacentExtendLaneStructEvent(token.GetAdjacentExtendLaneStructEvent()),
          SMAStructEvent(token.GetSMAStructEvent()),
          WPExtendLaneStructEvent(token.GetWPExtendLaneStructEvent()),
          RemindWayPointStructEvent(token.GetRemindWayPointStructEvent()),
          ControlWayPointStructEvent(token.GetControlWayPointStructEvent()),
          MsgHeaderEvent(token.GetMsgHeaderEvent()),
          TransitLaneStructEvent(token.GetTransitLaneStructEvent()),
          ControlWayPointsEvent(token.GetControlWayPointsEvent()),
          SLAMLocalEgoOdomEvent(token.GetSLAMLocalEgoOdomEvent()),
          SLAMOdometryEvent(token.GetSLAMOdometryEvent()){
        static_cast<void>(std::move(token));
    }

    static ara::core::Result<ConstructionToken> Preconstruct(
        const ara::com::HandleType &handle)
    {
        std::shared_ptr<ara::com::internal::proxy::ProxyAdapter> preProxyAdapter =
            std::make_shared<ara::com::internal::proxy::ProxyAdapter>(
               ::jac::ap::slamservice::SLAMService::ServiceIdentifier, handle);
        ConstructionToken token{std::move(preProxyAdapter)};
        ara::core::Result<void> initResult {token.InitializeAll()};
        if (initResult.HasValue()) {
            return ara::core::Result<ConstructionToken>(std::move(token));
        } else {
            const ara::core::ErrorCode errorcode{initResult.Error()};
            ara::core::Result<SLAMServiceProxy::ConstructionToken> preResult{errorcode};
            return preResult;
        }
    }

    static ara::com::FindServiceHandle StartFindService(
        const ara::com::FindServiceHandler<ara::com::internal::proxy::ProxyAdapter::HandleType>& handler,
        const ara::com::InstanceIdentifier instance)
    {
        return ara::com::internal::proxy::ProxyAdapter::StartFindService(handler, ::jac::ap::slamservice::SLAMService::ServiceIdentifier, instance);
    }

    static ara::com::FindServiceHandle StartFindService(
        const ara::com::FindServiceHandler<ara::com::internal::proxy::ProxyAdapter::HandleType> handler,
        const ara::core::InstanceSpecifier specifier)
    {
        return ara::com::internal::proxy::ProxyAdapter::StartFindService(handler, ::jac::ap::slamservice::SLAMService::ServiceIdentifier, specifier);
    }

    static ara::com::ServiceHandleContainer<ara::com::internal::proxy::ProxyAdapter::HandleType> FindService(
        const ara::com::InstanceIdentifier instance)
    {
        return ara::com::internal::proxy::ProxyAdapter::FindService(::jac::ap::slamservice::SLAMService::ServiceIdentifier, instance);
    }

    static ara::com::ServiceHandleContainer<ara::com::internal::proxy::ProxyAdapter::HandleType> FindService(
        const ara::core::InstanceSpecifier specifier)
    {
        return ara::com::internal::proxy::ProxyAdapter::FindService(::jac::ap::slamservice::SLAMService::ServiceIdentifier, specifier);
    }

    static void StopFindService(const ara::com::FindServiceHandle& handle)
    {
        ara::com::internal::proxy::ProxyAdapter::StopFindService(handle);
    }

    HandleType GetHandle() const
    {
        return proxyAdapter->GetHandle();
    }
    bool SetEventThreadNumber(const std::uint16_t number, const std::uint16_t queueSize)
    {
        return proxyAdapter->SetEventThreadNumber(number, queueSize);
    }
    events::PositionEvent PositionEvent;
    events::AttributeEvent AttributeEvent;
    events::LinePointEvent LinePointEvent;
    events::LineEvent LineEvent;
    events::SpeedLimitEvent SpeedLimitEvent;
    events::TrafficObjectEvent TrafficObjectEvent;
    events::LaneEventSlam LaneEventSlam;
    events::RoadEdgeEvent RoadEdgeEvent;
    events::SLAMRoadModelEvent SLAMRoadModelEvent;
    events::AdjacentExtendLaneStructEvent AdjacentExtendLaneStructEvent;
    events::SMAStructEvent SMAStructEvent;
    events::WPExtendLaneStructEvent WPExtendLaneStructEvent;
    events::RemindWayPointStructEvent RemindWayPointStructEvent;
    events::ControlWayPointStructEvent ControlWayPointStructEvent;
    events::MsgHeaderEvent MsgHeaderEvent;
    events::TransitLaneStructEvent TransitLaneStructEvent;
    events::ControlWayPointsEvent ControlWayPointsEvent;
    events::SLAMLocalEgoOdomEvent SLAMLocalEgoOdomEvent;
    events::SLAMOdometryEvent SLAMOdometryEvent;
};
} // namespace proxy
} // namespace slamservice
} // namespace ap
} // namespace jac

#endif // JAC_AP_SLAMSERVICE_SLAMSERVICE_PROXY_H
